"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const sqlite3_1 = __importDefault(require("sqlite3"));
const sqlite_1 = require("sqlite");
const SQL = require('sql-template-strings');
const path_1 = require("path");
class SqliteStoreBase {
    constructor(config) {
        this.hasInit = false;
        this.config = config;
        this.prefix = config.prefix || '';
        this.db = null;
    }
    getSid(sid) {
        return this.prefix + sid;
    }
    async init() {
        if (!this.db) {
            this.db = await sqlite_1.open({
                filename: this.config.path,
                driver: sqlite3_1.default.Database
            });
            await this.db.migrate({
                migrationsPath: path_1.join(__dirname, 'migrations')
            });
            this.hasInit = true;
        }
    }
    async get(sid) {
        await this.init();
        const time = new Date().getTime();
        const resp = await this.db.get(SQL `SELECT * FROM sessions WHERE sid = ${this.getSid(sid)} AND ${time} < expires`);
        if (!resp) {
            return null;
        }
        return JSON.parse(resp.data);
    }
    async set(sid, session) {
        await this.init();
        const serialized = JSON.stringify(session);
        const msTtl = new Date().getTime() + this.config.ttl;
        const stmt = await this.db.prepare('INSERT INTO sessions (sid, data, expires) VALUES (:sid, :data, :expires)', {
            ':sid': this.getSid(sid),
            ':data': serialized,
            ':expires': msTtl
        });
        await stmt.run();
    }
    async destroy(sid) {
        await this.init();
        await this.db.run(SQL `DELETE FROM sessions WHERE sid = ${this.getSid(sid)}`);
    }
    async all() {
        await this.init();
        const time = new Date().getTime();
        const data = await this.db.all(`SELECT * FROM sessions WHERE ${time} < expires`);
        return data.map(raw => {
            return JSON.parse(raw.data);
        });
    }
    async length() {
        await this.init();
        const time = new Date().getTime();
        const data = await this.db.get(`SELECT count(*) as total FROM sessions WHERE ${time} < expires`);
        return data.total;
    }
    async clear() {
        await this.init();
        await this.db.run(`DELETE FROM sessions`);
    }
    async touch(sid, session) {
        await this.init();
        await this.destroy(sid);
        await this.set(sid, session);
    }
    /**
     * Have to manually call this to remove stale entries
     */
    async removeExpiredSessions() {
        await this.init();
        const time = new Date().getTime();
        await this.db.run(`DELETE FROM sessions WHERE ${time} > expires`);
    }
}
exports.SqliteStoreBase = SqliteStoreBase;
//# sourceMappingURL=SqliteStoreBase.js.map